/* *******************************************************************
   OpenWeather API 3.0
   
   exclude minutely,hourly
   units   (standard, metric, imperial)  --> metric
   lang                                  --> de, en, (alfa2)

   example call (with invalid key:
   http://api.openweathermap.org/data/3.0/onecall?lat=48.2083&lon=16.3731&exclude=minutely,hourly&units=metric&appid=0011223344556677889900aabbccddeeff

   ***************************************************************** */
#pragma once

enum Returncode {NO_DATA, NEW_DATA};   

constexpr char owAPI[] {"http://api.openweathermap.org/data/3.0/onecall"};     // URL for the Openweathermap V3.0

/* 
  @brief gets new weather data
  @returns a constants for NO_DATA or NEW_DATA
*/
int weatherUpdate() {
  Serial.println(F("get new weather data"));
  String url;
  url.reserve(500);
  url = owAPI;                                   // the URL
  url += "?lat="; url += String(owLat, 6);       // your parameters
  url += "&lon="; url += String(owLon, 6);
  url += "&units="; url += owUnits;
  url += "&lang="; url += owLang;
  url += "&exclude="; url += owExclude;
  url += "&appid="; url += owKey;                // your APP ID (the key)
  Serial.println(url);                          

  WiFiClient client;                   // or WiFiClientSecure for HTTPS
  HTTPClient http;

  // Send request
  http.useHTTP10(true);                // see https://arduinojson.org/v7/how-to/use-arduinojson-with-httpclient/
  http.begin(client, url);
  http.GET();

  // Parse response
  JsonDocument doc;
  DeserializationError error = deserializeJson(doc, http.getStream());
  if (error) {
    Serial.print(F("deserializeJson() failed: ")); Serial.println(error.f_str());
    http.end();
    return NO_DATA;
  }

  // Disconnect
  http.end();

  // Read values into the global weather structure

  JsonObject current = doc["current"];
  weather.current_dt = current["dt"];            // 1725638261
  weather.current_sunrise = current["sunrise"];  // 1725596374
  weather.current_sunset = current["sunset"];    // 1725643585
  weather.current_temp = current["temp"];        // 26.61
  weather.current_feels_like = current["feels_like"];      // 26.61
  weather.current_pressure = current["pressure"]; // 1013
  weather.current_humidity = current["humidity"]; // 42
  weather.current_dew_point = current["dew_point"];        // 12.65
  weather.current_uvi = current["uvi"];           // 0.4
  weather.current_clouds = current["clouds"];     // 0
  weather.current_visibility = current["visibility"];      // 10000
  weather.current_wind_speed = current["wind_speed"];      // 5.14
  weather.current_wind_deg = current["wind_deg"]; // 140

  JsonObject current_weather_0 = current["weather"][0];
  weather.current_weather_0_id = current_weather_0["id"];  // 800
  weather.current_weather_0_main = current_weather_0["main"].as<String>();     // "Clear"
  weather.current_weather_0_description = current_weather_0["description"].as<String>(); // "clear sky"
  weather.current_weather_0_icon = current_weather_0["icon"].as<String>();     // "01d"

  JsonArray daily = doc["daily"];
  JsonObject daily_0 = daily[0];
  weather.daily_0_summary = daily_0["summary"].as<String>();         // "There will be rain until morning, then partly ...

  if (doc.containsKey("alerts")) {     // other version // https://github.com/bblanchon/ArduinoJson/issues/2070 didn't work with ArduinoJSON 7
    //Serial.println(F("contains alerts"));
    JsonObject alerts_0 = doc["alerts"][0];
    weather.alerts_0_sender_name = alerts_0["sender_name"].as<String>();       // "GeoSphere Austria"
    weather.alerts_0_event = alerts_0["event"].as<String>();                   // "Heatwarning"
    weather.alerts_0_description = alerts_0["description"].as<String>();       // "Increased heat stress must be expected."
    weather.alerts_0_tags_0 = alerts_0["tags"][0].as<String>();                // "Extreme high temperature"
  }
  else {
    weather.alerts_0_sender_name = "";
    weather.alerts_0_event = "";
    weather.alerts_0_description = "";
    weather.alerts_0_tags_0 = "";
  }
  if (doc.containsKey("cod")) {
    weather.cod = doc["cod"];
    weather.message = doc["message"].as<String>();
    return weather.cod;
  } else {
    weather.cod = 0;
    weather.message = "";
  }
  //
  return NEW_DATA;
}

/* 
  @brief timer to call for new weather data
  @returns a constants for NO_DATA or NEW_DATA
*/
int weatherTimer(uint32_t currentMillis = millis()) {
  constexpr uint32_t interval = owInterval * 60 * 1000UL;
  static uint32_t previousMillis = 0 - interval;
  if (currentMillis - previousMillis > interval) {
    previousMillis = currentMillis;
    return weatherUpdate();
  }
  return NO_DATA; // nothing done
}
//