/* *******************************************************************
   O T A
   Over The Air update (via IDE)
   ***************************************************************** */
#pragma once

/* 
  @brief to be called in setup
*/
void ArduinoOTASetup() {
  //IDE OTA
#ifdef ARDUINO_ARCH_ESP32
  char myhostname[16] {"esp"};         // you could use your TXT_BOARDNAME also. The sketch will add the board ID.
  char val[8];
  itoa(USE_BOARD, val, 10);            // before we can concatenate the precompiler integer, we have to convert it to char array
  strcat(myhostname, val);
  ArduinoOTA.setHostname(myhostname);  // give a name to your ESP for the Arduino IDE - not needed for ESP8266
#endif
  ArduinoOTA.begin();                  // OTA Upload via ArduinoIDE https://arduino-esp8266.readthedocs.io/en/latest/ota_updates/readme.html
  // OTA Messages
  ArduinoOTA.onStart([]() {
    Serial.println(F("OTA Start"));
  });
  ArduinoOTA.onProgress([](unsigned int progress, unsigned int total) {
    static byte previous = 0;
    byte result = progress / (total / 100);
    if (previous != result) {
      if ((result % 10) == 0) {
        Serial.print(result);
        Serial.println("%");
      }
      else Serial.print(".");
    }
    previous = result;
  });
  ArduinoOTA.onEnd([]() {
    Serial.println(F("\nOTA End"));
  });
  ArduinoOTA.onError([](ota_error_t error) {
    Serial.printf("\nOTA Error[%u]: ", error);
    if (error == OTA_AUTH_ERROR) Serial.println(F("\nAuth Failed"));
    else if (error == OTA_BEGIN_ERROR) Serial.println(F("\nBegin Failed"));
    else if (error == OTA_CONNECT_ERROR) Serial.println(F("\nConnect Failed"));
    else if (error == OTA_RECEIVE_ERROR) Serial.println(F("\nReceive Failed"));
    else if (error == OTA_END_ERROR) Serial.println(F("\nEnd Failed"));
  });
}
//
