/*
   Further Information:
   Recommendation how to use ArduinoJSON with the HTTPClient
   https://arduinojson.org/v7/how-to/use-arduinojson-with-httpclient/

   Example message if you have an invalid API key:
   
{"cod":401, "message": "Please note that using One Call 3.0 requires a separate subscription to the One Call by Call plan. Learn more here https://openweathermap.org/price. If you have a valid subscription to the One Call by Call plan, but still receive this error, then please see https://openweathermap.org/faq#error401 for more info."}

   Example Arduino Code of a valid message:


  // Stream& input;

  float lat = doc["lat"]; // 48.2083
  float lon = doc["lon"]; // 16.3731
  const char* timezone = doc["timezone"]; // "Europe/Vienna"
  int timezone_offset = doc["timezone_offset"]; // 7200

  JsonObject current = doc["current"];
  long current_dt = current["dt"]; // 1724092445
  long current_sunrise = current["sunrise"]; // 1724039688
  long current_sunset = current["sunset"]; // 1724090501
  float current_temp = current["temp"]; // 19.93
  float current_feels_like = current["feels_like"]; // 20.07
  int current_pressure = current["pressure"]; // 1016
  int current_humidity = current["humidity"]; // 80
  float current_dew_point = current["dew_point"]; // 16.38
  int current_uvi = current["uvi"]; // 0
  int current_clouds = current["clouds"]; // 75
  int current_visibility = current["visibility"]; // 10000
  float current_wind_speed = current["wind_speed"]; // 12.07
  int current_wind_deg = current["wind_deg"]; // 347
  float current_wind_gust = current["wind_gust"]; // 25.03

  JsonObject current_weather_0 = current["weather"][0];
  int current_weather_0_id = current_weather_0["id"]; // 803
  const char* current_weather_0_main = current_weather_0["main"]; // "Clouds"
  const char* current_weather_0_description = current_weather_0["description"]; // "broken clouds"
  const char* current_weather_0_icon = current_weather_0["icon"]; // "04n"

  JsonArray daily = doc["daily"];

  JsonObject daily_0 = daily[0];
  long daily_0_dt = daily_0["dt"]; // 1724061600
  long daily_0_sunrise = daily_0["sunrise"]; // 1724039688
  long daily_0_sunset = daily_0["sunset"]; // 1724090501
  long daily_0_moonrise = daily_0["moonrise"]; // 1724091360
  long daily_0_moonset = daily_0["moonset"]; // 1724036100
  float daily_0_moon_phase = daily_0["moon_phase"]; // 0.5
  const char* daily_0_summary = daily_0["summary"]; // "There will be rain until morning, then partly ...

  JsonObject daily_0_temp = daily_0["temp"];
  float daily_0_temp_day = daily_0_temp["day"]; // 24.1
  float daily_0_temp_min = daily_0_temp["min"]; // 19.8
  float daily_0_temp_max = daily_0_temp["max"]; // 24.42
  float daily_0_temp_night = daily_0_temp["night"]; // 19.82
  float daily_0_temp_eve = daily_0_temp["eve"]; // 19.88
  float daily_0_temp_morn = daily_0_temp["morn"]; // 20.06

  JsonObject daily_0_feels_like = daily_0["feels_like"];
  float daily_0_feels_like_day = daily_0_feels_like["day"]; // 24.24
  float daily_0_feels_like_night = daily_0_feels_like["night"]; // 19.92
  float daily_0_feels_like_eve = daily_0_feels_like["eve"]; // 19.93
  float daily_0_feels_like_morn = daily_0_feels_like["morn"]; // 20.26

  int daily_0_pressure = daily_0["pressure"]; // 1013
  int daily_0_humidity = daily_0["humidity"]; // 64
  float daily_0_dew_point = daily_0["dew_point"]; // 16.65
  float daily_0_wind_speed = daily_0["wind_speed"]; // 7.48
  int daily_0_wind_deg = daily_0["wind_deg"]; // 284
  float daily_0_wind_gust = daily_0["wind_gust"]; // 15.14

  JsonObject daily_0_weather_0 = daily_0["weather"][0];
  int daily_0_weather_0_id = daily_0_weather_0["id"]; // 501
  const char* daily_0_weather_0_main = daily_0_weather_0["main"]; // "Rain"
  const char* daily_0_weather_0_description = daily_0_weather_0["description"]; // "moderate rain"
  const char* daily_0_weather_0_icon = daily_0_weather_0["icon"]; // "10d"

  int daily_0_clouds = daily_0["clouds"]; // 91
  int daily_0_pop = daily_0["pop"]; // 1
  float daily_0_rain = daily_0["rain"]; // 2.97
  float daily_0_uvi = daily_0["uvi"]; // 2.17

  JsonObject daily_1 = daily[1];
  long daily_1_dt = daily_1["dt"]; // 1724148000
  long daily_1_sunrise = daily_1["sunrise"]; // 1724126171
  long daily_1_sunset = daily_1["sunset"]; // 1724176791
  long daily_1_moonrise = daily_1["moonrise"]; // 1724178900
  long daily_1_moonset = daily_1["moonset"]; // 1724127780
  float daily_1_moon_phase = daily_1["moon_phase"]; // 0.52
  const char* daily_1_summary = daily_1["summary"]; // "You can expect partly cloudy in the morning, with ...

  JsonObject daily_1_temp = daily_1["temp"];
  float daily_1_temp_day = daily_1_temp["day"]; // 25.63
  float daily_1_temp_min = daily_1_temp["min"]; // 18.33
  float daily_1_temp_max = daily_1_temp["max"]; // 30.29
  float daily_1_temp_night = daily_1_temp["night"]; // 21.98
  float daily_1_temp_eve = daily_1_temp["eve"]; // 29.98
  float daily_1_temp_morn = daily_1_temp["morn"]; // 18.33

  JsonObject daily_1_feels_like = daily_1["feels_like"];
  float daily_1_feels_like_day = daily_1_feels_like["day"]; // 25.74
  float daily_1_feels_like_night = daily_1_feels_like["night"]; // 22.4
  float daily_1_feels_like_eve = daily_1_feels_like["eve"]; // 30.03
  float daily_1_feels_like_morn = daily_1_feels_like["morn"]; // 18.44

  int daily_1_pressure = daily_1["pressure"]; // 1013
  int daily_1_humidity = daily_1["humidity"]; // 57
  float daily_1_dew_point = daily_1["dew_point"]; // 16.26
  float daily_1_wind_speed = daily_1["wind_speed"]; // 4.78
  int daily_1_wind_deg = daily_1["wind_deg"]; // 306
  float daily_1_wind_gust = daily_1["wind_gust"]; // 10.08

  JsonObject daily_1_weather_0 = daily_1["weather"][0];
  int daily_1_weather_0_id = daily_1_weather_0["id"]; // 501
  const char* daily_1_weather_0_main = daily_1_weather_0["main"]; // "Rain"
  const char* daily_1_weather_0_description = daily_1_weather_0["description"]; // "moderate rain"
  const char* daily_1_weather_0_icon = daily_1_weather_0["icon"]; // "10d"

  int daily_1_clouds = daily_1["clouds"]; // 90
  int daily_1_pop = daily_1["pop"]; // 1
  float daily_1_rain = daily_1["rain"]; // 2.86
  float daily_1_uvi = daily_1["uvi"]; // 4.79

  JsonObject daily_2 = daily[2];
  long daily_2_dt = daily_2["dt"]; // 1724234400
  long daily_2_sunrise = daily_2["sunrise"]; // 1724212654
  long daily_2_sunset = daily_2["sunset"]; // 1724263079
  long daily_2_moonrise = daily_2["moonrise"]; // 1724266380
  long daily_2_moonset = daily_2["moonset"]; // 1724219460
  float daily_2_moon_phase = daily_2["moon_phase"]; // 0.56
  const char* daily_2_summary = daily_2["summary"]; // "Expect a day of partly cloudy with rain"

  JsonObject daily_2_temp = daily_2["temp"];
  float daily_2_temp_day = daily_2_temp["day"]; // 25.14
  float daily_2_temp_min = daily_2_temp["min"]; // 20.34
  float daily_2_temp_max = daily_2_temp["max"]; // 26.45
  float daily_2_temp_night = daily_2_temp["night"]; // 20.6
  float daily_2_temp_eve = daily_2_temp["eve"]; // 25.8
  float daily_2_temp_morn = daily_2_temp["morn"]; // 20.39

  JsonObject daily_2_feels_like = daily_2["feels_like"];
  float daily_2_feels_like_day = daily_2_feels_like["day"]; // 25.04
  float daily_2_feels_like_night = daily_2_feels_like["night"]; // 20.49
  float daily_2_feels_like_eve = daily_2_feels_like["eve"]; // 25.61
  float daily_2_feels_like_morn = daily_2_feels_like["morn"]; // 20.6

  int daily_2_pressure = daily_2["pressure"]; // 1014
  int daily_2_humidity = daily_2["humidity"]; // 51
  float daily_2_dew_point = daily_2["dew_point"]; // 14.2
  float daily_2_wind_speed = daily_2["wind_speed"]; // 5.74
  int daily_2_wind_deg = daily_2["wind_deg"]; // 284
  float daily_2_wind_gust = daily_2["wind_gust"]; // 13.26

  JsonObject daily_2_weather_0 = daily_2["weather"][0];
  int daily_2_weather_0_id = daily_2_weather_0["id"]; // 500
  const char* daily_2_weather_0_main = daily_2_weather_0["main"]; // "Rain"
  const char* daily_2_weather_0_description = daily_2_weather_0["description"]; // "light rain"
  const char* daily_2_weather_0_icon = daily_2_weather_0["icon"]; // "10d"

  int daily_2_clouds = daily_2["clouds"]; // 100
  float daily_2_pop = daily_2["pop"]; // 0.97
  float daily_2_rain = daily_2["rain"]; // 0.35
  float daily_2_uvi = daily_2["uvi"]; // 5.4

  JsonObject daily_3 = daily[3];
  long daily_3_dt = daily_3["dt"]; // 1724320800
  long daily_3_sunrise = daily_3["sunrise"]; // 1724299136
  long daily_3_sunset = daily_3["sunset"]; // 1724349367
  long daily_3_moonrise = daily_3["moonrise"]; // 1724353800
  long daily_3_moonset = daily_3["moonset"]; // 1724311020
  float daily_3_moon_phase = daily_3["moon_phase"]; // 0.6
  const char* daily_3_summary = daily_3["summary"]; // "There will be partly cloudy today"

  JsonObject daily_3_temp = daily_3["temp"];
  float daily_3_temp_day = daily_3_temp["day"]; // 22.79
  float daily_3_temp_min = daily_3_temp["min"]; // 16.61
  float daily_3_temp_max = daily_3_temp["max"]; // 25.65
  float daily_3_temp_night = daily_3_temp["night"]; // 21.77
  float daily_3_temp_eve = daily_3_temp["eve"]; // 25.06
  float daily_3_temp_morn = daily_3_temp["morn"]; // 16.61

  JsonObject daily_3_feels_like = daily_3["feels_like"];
  float daily_3_feels_like_day = daily_3_feels_like["day"]; // 22.06
  float daily_3_feels_like_night = daily_3_feels_like["night"]; // 21.33
  float daily_3_feels_like_eve = daily_3_feels_like["eve"]; // 24.59
  float daily_3_feels_like_morn = daily_3_feels_like["morn"]; // 15.97

  int daily_3_pressure = daily_3["pressure"]; // 1017
  int daily_3_humidity = daily_3["humidity"]; // 36
  float daily_3_dew_point = daily_3["dew_point"]; // 6.76
  float daily_3_wind_speed = daily_3["wind_speed"]; // 4.47
  int daily_3_wind_deg = daily_3["wind_deg"]; // 296
  float daily_3_wind_gust = daily_3["wind_gust"]; // 11.03

  JsonObject daily_3_weather_0 = daily_3["weather"][0];
  int daily_3_weather_0_id = daily_3_weather_0["id"]; // 804
  const char* daily_3_weather_0_main = daily_3_weather_0["main"]; // "Clouds"
  const char* daily_3_weather_0_description = daily_3_weather_0["description"]; // "overcast clouds"
  const char* daily_3_weather_0_icon = daily_3_weather_0["icon"]; // "04d"

  int daily_3_clouds = daily_3["clouds"]; // 100
  int daily_3_pop = daily_3["pop"]; // 0
  float daily_3_uvi = daily_3["uvi"]; // 5.7

  JsonObject daily_4 = daily[4];
  long daily_4_dt = daily_4["dt"]; // 1724407200
  long daily_4_sunrise = daily_4["sunrise"]; // 1724385619
  long daily_4_sunset = daily_4["sunset"]; // 1724435654
  long daily_4_moonrise = daily_4["moonrise"]; // 1724441280
  long daily_4_moonset = daily_4["moonset"]; // 1724402460
  float daily_4_moon_phase = daily_4["moon_phase"]; // 0.64
  const char* daily_4_summary = daily_4["summary"]; // "Expect a day of partly cloudy with clear spells"

  JsonObject daily_4_temp = daily_4["temp"];
  float daily_4_temp_day = daily_4_temp["day"]; // 26.51
  float daily_4_temp_min = daily_4_temp["min"]; // 18.79
  float daily_4_temp_max = daily_4_temp["max"]; // 32.17
  float daily_4_temp_night = daily_4_temp["night"]; // 25.52
  float daily_4_temp_eve = daily_4_temp["eve"]; // 32.17
  float daily_4_temp_morn = daily_4_temp["morn"]; // 18.79

  JsonObject daily_4_feels_like = daily_4["feels_like"];
  float daily_4_feels_like_day = daily_4_feels_like["day"]; // 26.51
  float daily_4_feels_like_night = daily_4_feels_like["night"]; // 25.46
  float daily_4_feels_like_eve = daily_4_feels_like["eve"]; // 31.13
  float daily_4_feels_like_morn = daily_4_feels_like["morn"]; // 18.4

  int daily_4_pressure = daily_4["pressure"]; // 1016
  int daily_4_humidity = daily_4["humidity"]; // 46
  float daily_4_dew_point = daily_4["dew_point"]; // 13.74
  float daily_4_wind_speed = daily_4["wind_speed"]; // 2.01
  int daily_4_wind_deg = daily_4["wind_deg"]; // 117
  float daily_4_wind_gust = daily_4["wind_gust"]; // 3.02

  JsonObject daily_4_weather_0 = daily_4["weather"][0];
  int daily_4_weather_0_id = daily_4_weather_0["id"]; // 800
  const char* daily_4_weather_0_main = daily_4_weather_0["main"]; // "Clear"
  const char* daily_4_weather_0_description = daily_4_weather_0["description"]; // "clear sky"
  const char* daily_4_weather_0_icon = daily_4_weather_0["icon"]; // "01d"

  int daily_4_clouds = daily_4["clouds"]; // 8
  int daily_4_pop = daily_4["pop"]; // 0
  float daily_4_uvi = daily_4["uvi"]; // 6.03

  JsonObject daily_5 = daily[5];
  long daily_5_dt = daily_5["dt"]; // 1724493600
  long daily_5_sunrise = daily_5["sunrise"]; // 1724472102
  long daily_5_sunset = daily_5["sunset"]; // 1724521939
  long daily_5_moonrise = daily_5["moonrise"]; // 1724528940
  long daily_5_moonset = daily_5["moonset"]; // 1724494020
  float daily_5_moon_phase = daily_5["moon_phase"]; // 0.68
  const char* daily_5_summary = daily_5["summary"]; // "Expect a day of partly cloudy with clear spells"

  JsonObject daily_5_temp = daily_5["temp"];
  float daily_5_temp_day = daily_5_temp["day"]; // 28.7
  float daily_5_temp_min = daily_5_temp["min"]; // 21.84
  float daily_5_temp_max = daily_5_temp["max"]; // 34.61
  float daily_5_temp_night = daily_5_temp["night"]; // 27.69
  float daily_5_temp_eve = daily_5_temp["eve"]; // 34.61
  float daily_5_temp_morn = daily_5_temp["morn"]; // 21.84

  JsonObject daily_5_feels_like = daily_5["feels_like"];
  float daily_5_feels_like_day = daily_5_feels_like["day"]; // 28.39
  float daily_5_feels_like_night = daily_5_feels_like["night"]; // 27.73
  float daily_5_feels_like_eve = daily_5_feels_like["eve"]; // 33.41
  float daily_5_feels_like_morn = daily_5_feels_like["morn"]; // 21.65

  int daily_5_pressure = daily_5["pressure"]; // 1016
  int daily_5_humidity = daily_5["humidity"]; // 41
  float daily_5_dew_point = daily_5["dew_point"]; // 13.93
  float daily_5_wind_speed = daily_5["wind_speed"]; // 5.12
  int daily_5_wind_deg = daily_5["wind_deg"]; // 180
  float daily_5_wind_gust = daily_5["wind_gust"]; // 9.14

  JsonObject daily_5_weather_0 = daily_5["weather"][0];
  int daily_5_weather_0_id = daily_5_weather_0["id"]; // 800
  const char* daily_5_weather_0_main = daily_5_weather_0["main"]; // "Clear"
  const char* daily_5_weather_0_description = daily_5_weather_0["description"]; // "clear sky"
  const char* daily_5_weather_0_icon = daily_5_weather_0["icon"]; // "01d"

  int daily_5_clouds = daily_5["clouds"]; // 7
  int daily_5_pop = daily_5["pop"]; // 0
  int daily_5_uvi = daily_5["uvi"]; // 7

  JsonObject daily_6 = daily[6];
  long daily_6_dt = daily_6["dt"]; // 1724580000
  long daily_6_sunrise = daily_6["sunrise"]; // 1724558585
  long daily_6_sunset = daily_6["sunset"]; // 1724608224
  long daily_6_moonrise = daily_6["moonrise"]; // 1724616840
  long daily_6_moonset = daily_6["moonset"]; // 1724585520
  float daily_6_moon_phase = daily_6["moon_phase"]; // 0.72
  const char* daily_6_summary = daily_6["summary"]; // "Expect a day of partly cloudy with rain"

  JsonObject daily_6_temp = daily_6["temp"];
  float daily_6_temp_day = daily_6_temp["day"]; // 28.82
  float daily_6_temp_min = daily_6_temp["min"]; // 21.73
  float daily_6_temp_max = daily_6_temp["max"]; // 31.7
  float daily_6_temp_night = daily_6_temp["night"]; // 21.73
  float daily_6_temp_eve = daily_6_temp["eve"]; // 31.25
  float daily_6_temp_morn = daily_6_temp["morn"]; // 23.82

  JsonObject daily_6_feels_like = daily_6["feels_like"];
  float daily_6_feels_like_day = daily_6_feels_like["day"]; // 28.99
  float daily_6_feels_like_night = daily_6_feels_like["night"]; // 22.07
  float daily_6_feels_like_eve = daily_6_feels_like["eve"]; // 31.09
  float daily_6_feels_like_morn = daily_6_feels_like["morn"]; // 23.69

  int daily_6_pressure = daily_6["pressure"]; // 1015
  int daily_6_humidity = daily_6["humidity"]; // 46
  float daily_6_dew_point = daily_6["dew_point"]; // 16.02
  float daily_6_wind_speed = daily_6["wind_speed"]; // 7.66
  int daily_6_wind_deg = daily_6["wind_deg"]; // 284
  float daily_6_wind_gust = daily_6["wind_gust"]; // 14.12

  JsonObject daily_6_weather_0 = daily_6["weather"][0];
  int daily_6_weather_0_id = daily_6_weather_0["id"]; // 500
  const char* daily_6_weather_0_main = daily_6_weather_0["main"]; // "Rain"
  const char* daily_6_weather_0_description = daily_6_weather_0["description"]; // "light rain"
  const char* daily_6_weather_0_icon = daily_6_weather_0["icon"]; // "10d"

  int daily_6_clouds = daily_6["clouds"]; // 2
  int daily_6_pop = daily_6["pop"]; // 1
  float daily_6_rain = daily_6["rain"]; // 1.92
  int daily_6_uvi = daily_6["uvi"]; // 7

  JsonObject daily_7 = daily[7];
  long daily_7_dt = daily_7["dt"]; // 1724666400
  long daily_7_sunrise = daily_7["sunrise"]; // 1724645068
  long daily_7_sunset = daily_7["sunset"]; // 1724694508
  long daily_7_moonrise = daily_7["moonrise"]; // 1724705280
  long daily_7_moonset = daily_7["moonset"]; // 1724676780
  float daily_7_moon_phase = daily_7["moon_phase"]; // 0.75
  const char* daily_7_summary = daily_7["summary"]; // "Expect a day of partly cloudy with rain"

  JsonObject daily_7_temp = daily_7["temp"];
  float daily_7_temp_day = daily_7_temp["day"]; // 24.23
  float daily_7_temp_min = daily_7_temp["min"]; // 18.99
  float daily_7_temp_max = daily_7_temp["max"]; // 26.22
  float daily_7_temp_night = daily_7_temp["night"]; // 18.99
  float daily_7_temp_eve = daily_7_temp["eve"]; // 25.56
  float daily_7_temp_morn = daily_7_temp["morn"]; // 19.11

  JsonObject daily_7_feels_like = daily_7["feels_like"];
  float daily_7_feels_like_day = daily_7_feels_like["day"]; // 24.07
  float daily_7_feels_like_night = daily_7_feels_like["night"]; // 19.16
  float daily_7_feels_like_eve = daily_7_feels_like["eve"]; // 25.48
  float daily_7_feels_like_morn = daily_7_feels_like["morn"]; // 19.24

  int daily_7_pressure = daily_7["pressure"]; // 1012
  int daily_7_humidity = daily_7["humidity"]; // 52
  float daily_7_dew_point = daily_7["dew_point"]; // 13.56
  float daily_7_wind_speed = daily_7["wind_speed"]; // 4.85
  int daily_7_wind_deg = daily_7["wind_deg"]; // 326
  float daily_7_wind_gust = daily_7["wind_gust"]; // 10.27

  JsonObject daily_7_weather_0 = daily_7["weather"][0];
  int daily_7_weather_0_id = daily_7_weather_0["id"]; // 500
  const char* daily_7_weather_0_main = daily_7_weather_0["main"]; // "Rain"
  const char* daily_7_weather_0_description = daily_7_weather_0["description"]; // "light rain"
  const char* daily_7_weather_0_icon = daily_7_weather_0["icon"]; // "10d"

  int daily_7_clouds = daily_7["clouds"]; // 81
  int daily_7_pop = daily_7["pop"]; // 1
  float daily_7_rain = daily_7["rain"]; // 2.67
  int daily_7_uvi = daily_7["uvi"]; // 7

*/
